mysql.conversion.output.Output_Conversion

Package mysql :: Package conversion :: Module output :: Class Output_Conversion |
[hide private]
[frames] | no frames]

# Class Output_Conversion

source code

Known Subclasses:
  Basic_Conversion, No_Conversion

Base class for the output conversion API.

The basic requirement is to implement the convert method which takes the value and returns a Python value.

Instance Methods | [hide private]
`` | convert(self, mysql_type, value) Convert a MySQL value to a Python object.

Method Details | [hide private]

### convert(self, mysql_type, value) | source code
Convert a MySQL value to a Python object. Parameters: `mysql_type` - The type from mysql.constants.field_types. `value` - The value from MySQL as a string. Returns: Returns the Python object.